@@ -1,6 +1,6 @@
 package Text::vCard::Precisely;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -101,13 +101,13 @@ Android 4.4.x can't parse vCard4.0
 To handle an address book with several vCard entries in it, start with
 L<Text::vFile::asData|https://metacpan.org/pod/Text::vFile::asData> and then come back to this module.
 
-Note that the vCard RFC requires version() and full_name().  This module does not check or warn yet if these conditions have not been met
+Note that the vCard RFC requires C<VERSION> and C<FN>.  This module does not check or warn yet if these conditions have not been met
 
 =head1 Constructors
 
 =head2 load_hashref($HashRef)
 
-Accepts an HashRef that looks like below:
+Accepts a HashRef that looks like below:
 
  my $hashref = {
     N   => [ 'Gump', 'Forrest', '', 'Mr.', '' ],
@@ -156,7 +156,7 @@ Accepts a vCard string
 =head2 as_string()
 
 Returns the vCard as a string.
-You have to use Encode::encode_utf8() if your vCard is written in utf8
+You have to use C<Encode::encode_utf8()> if your vCard is written in utf8
 
 =head2 as_file($filename)
 
@@ -179,15 +179,16 @@ To specify revision information about the current vCard
 =head2 sort_string()
 
 To specify the family name, given name or organization text to be used for
-national-language-specific sorting of the FN, N and ORG.
+national-language-specific sorting of the C<FN>, C<N> and C<ORG>.
 
-B<This method is DEPRECATED in vCard4.0> Use SORT-AS param instead of it.
+B<This method is DEPRECATED in vCard4.0> Use C<SORT-AS> param instead of it.
 
 =head1 COMPLEX GETTERS/SETTERS
 
 They are based on Moose with coercion.
-So these methods accept not only ArrayRef[HashRef] but also ArrayRef[Str], single HashRef
-or single Str.
+So these methods accept not only ArrayRef[HashRef] but also ArrayRef[Str],
+single HashRef or single Str.
+
 Read source if you were confused
 
 =head2 n()
@@ -203,7 +204,9 @@ Accepts/returns an ArrayRef that looks like:
     { type => ['home'], content => '651-290-1111' },
  ]
 
-After version 0.18, B<content will not be validated as phone numbers> All I<Str> type is accepted.
+After version 0.18, B<content will not be validated as phone numbers> 
+All I<Str> type is accepted.
+
 So you have to validate phone numbers with your way.
 
 =head2 adr(), address()
@@ -252,8 +255,8 @@ or accept the string as URL like below
 
 =head2 photo(), logo()
 
-Accepts/returns an ArrayRef of URLs or Images: Even if they are raw image binary
- or text encoded in Base64, it does not matter
+Accepts/returns an ArrayRef of URLs or Images: 
+Even if they are raw image binary or text encoded in Base64, it does not matter
 
 B<Attention!> Mac OS X and iOS B<ignore> the description beeing URL
 
@@ -275,18 +278,6 @@ A person's entire name as they would like to see it displayed
 
 To specify the text corresponding to the nickname of the object the vCard represents
 
-=head2 lang()
-
-To specify the language(s) that may be used for contacting the entity associated with the vCard.
-
-It's the B<new method from 4.0>
-
-=head2 impp(), xml()
-
-I don't think they are so popular types, but here are the methods!
-
-They are the B<new method from 4.0>
-
 =head2 geo()
 
 To specify information related to the global positioning of the object the vCard represents
@@ -297,32 +288,14 @@ To specify a public key or authentication certificate associated with the object
 
 =head2 label()
 
-ToDo: because B<It's DEPRECATED from 4.0>
+ToDo: because B<It's DEPRECATED in vCard4.0>
 
 To specify the formatted text corresponding to delivery address of the object the vCard represents
 
 =head2 uid()
 
-To specify a value that represents a globally unique identifier corresponding to the individual
-or resource associated with the vCard
-
-=head2 fburl(), caladruri(), caluri()
-
-I don't think they are so popular types, but here are the methods!
-
-They are the B<new method from 4.0>
-
-=head2 kind()
-
-To specify the kind of object the vCard represents
-
-It's the B<new method from 4.0>
-
-=head2 member(), clientpidmap()
-
-I don't think they are so popular types, but here are the methods!
-
-It's the B<new method from 4.0>
+To specify a value that represents a globally unique identifier corresponding to 
+the individual or resource associated with the vCard
 
 =head2 tz(), timezone()
 
@@ -330,10 +303,12 @@ Both are same method with Alias
 
 To specify information related to the time zone of the object the vCard represents
 
-utc-offset format is NOT RECOMMENDED in vCard 4.0
+utc-offset format is NOT RECOMMENDED from vCard4.0
 
-TZ can be a URL, but there is no document in L<RFC2426|https://tools.ietf.org/html/rfc2426>
+C<TZ> can be a URL, but there is no document in
+ L<RFC2426|https://tools.ietf.org/html/rfc2426>
 or L<RFC6350|https://tools.ietf.org/html/rfc6350>
+
 So it just supports some text values
 
 =head2 bday(), birthday()
@@ -342,18 +317,6 @@ Both are same method with Alias
 
 To specify the birth date of the object the vCard represents
 
-=head2 anniversary()
-
-The date of marriage, or equivalent, of the object the vCard represents
-
-It's the B<new method from 4.0>
-
-=head2 gender()
-
-To specify the components of the sex and gender identity of the object the vCard represents
-
-It's the B<new method from 4.0>
-
 =head2 prodid()
 
 To specify the identifier for the product that created the vCard object
@@ -366,18 +329,18 @@ To identify the source of directory information contained in the content type
 
 To specify a digital sound content information that annotates some aspect of the vCard
 
-This property is often used to specify the proper pronunciation of the name property value
- of the vCard
+This property is often used to specify the proper pronunciation of 
+the name property value of the vCard
 
 =head2 socialprofile()
 
-There is no documents about X-SOCIALPROFILE in RFC but it works in iOS and Mac OS X!
+There is no documents about C<X-SOCIALPROFILE> in RFC but it works in iOS and Mac OS X!
 
 I don't know well about in Android or Windows. Somebody please feedback me
 
 =head2 label()
 
-B<It's DEPRECATED from 4.0> You can use this method Just ONLY in vCard3.0
+B<It's DEPRECATED in vCard4.0> You can use this method Just ONLY in vCard3.0
 
 =head1 For operating files with multiple vCards
 
@@ -385,7 +348,8 @@ See L<Text::vCard::Precisely::Multiple|https://metacpan.org/pod/Text::vCard::Pre
 
 =head1 aroud UTF-8
 
-If you want to send precisely the vCard with UTF-8 characters to the B<ALMOST> of smartphones, Use 3.0
+If you want to send precisely the vCard with UTF-8 characters to the B<ALMOST>
+of smartphones, Use 3.0
 
 It seems to be TOO EARLY to use 4.0
 
@@ -393,8 +357,6 @@ It seems to be TOO EARLY to use 4.0
 
 This module uses C<\P{ascii}> in regexp so You have to use 5.12.5 and later
 
-And this module uses Data::Validate::URI and it has bug on 5.8.x. so I can't support them
-
 =head1 SEE ALSO
 
 =over
